@@ -714,7 +714,9 @@ class CpanelBackupImporter {
     private function importDatabase($originalDbName, $sqlFile) {
         // Initialize mysqlmgmt if not already done
         if (!isset($this->mysqlMgmt)) {
-            require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            if (!class_exists('mysqlmgmt')) {
+                require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            }
             $this->mysqlMgmt = new mysqlmgmt();
         }
         
@@ -765,7 +767,9 @@ class CpanelBackupImporter {
     private function createMysqlUser($grant) {
         // Initialize mysqlmgmt if not already done
         if (!isset($this->mysqlMgmt)) {
-            require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            if (!class_exists('mysqlmgmt')) {
+                require_once('/docker/whp/web/libs/mysqlmgmt.php');
+            }
             $this->mysqlMgmt = new mysqlmgmt();
         }
         
@@ -904,14 +908,30 @@ class CpanelBackupImporter {
      */
     private function addDomainToSite($siteId, $domain) {
         try {
-            // This should integrate with your existing site management system
-            // For now, we'll add it to a simple additional_domains table or field
+            // Check if domain exists in WHP
+            $stmt = $this->pdo->prepare("SELECT id FROM whp.domains WHERE domain_name = ? AND username = ?");
+            $stmt->execute([$domain, $this->username]);
+            $domainRow = $stmt->fetch();
+            
+            if (!$domainRow) {
+                // Create domain first
+                $stmt = $this->pdo->prepare("
+                    INSERT INTO whp.domains (domain_name, username, active, created_at) 
+                    VALUES (?, ?, 1, NOW())
+                ");
+                $stmt->execute([$domain, $this->username]);
+                $domainId = $this->pdo->lastInsertId();
+            } else {
+                $domainId = $domainRow['id'];
+            }
+            
+            // Add to site_domains using the correct schema (domain_id, not domain)
             $stmt = $this->pdo->prepare("
-                INSERT INTO site_domains (site_id, domain, domain_type, created_at) 
-                VALUES (?, ?, 'additional', NOW())
-                ON DUPLICATE KEY UPDATE domain_type = 'additional'
+                INSERT INTO whp.site_domains (site_id, domain_id, is_primary) 
+                VALUES (?, ?, 0)
+                ON DUPLICATE KEY UPDATE is_primary = 0
             ");
-            $stmt->execute([$siteId, $domain]);
+            $stmt->execute([$siteId, $domainId]);
             
         } catch (PDOException $e) {
             $this->log("Failed to add domain " . $domain . " to site " . $siteId . ": " . $e->getMessage(), 'error');
